v1.1.1
======

#1: Fixed improper encoding of cell text values.

v1.1.0
======

Refreshed package.

v1.0.0
======

``Workbook`` and ``markup`` are no longer aliased in the ``xlsx`` module.

Require Python 3.6 or later.

0.4.1
=====

* Corrected syntax issue in readme.

0.4.0
=====

* Moved project to Github.
* Use Travis-CI for continuous integration and deployment.
* Use setuptools_scm for tagging releases.

0.3.0
=====

* Fixes for Python 3. Tests now pass on Python 3.

0.2.0
=====

* Improved compatibility with Python 3
* Add support for the style parameter on a column.
* Add support for 'best fit' parameter on a column.

0.1.6
=====

* Performance improvements (memory and speed)

